@@ -90,6 +90,10 @@ def push_to_backend(obj, level=None):
         backend_logger.log(level, obj)
 
 
+def push_quad(entity, attribute, value, action=None):
+    pass
+
+
 # to be used by itself _and_ extended
 class Context(object):
     '''
@@ -130,8 +134,8 @@ class Context(object):
                  # Common configuration
                  name=None,         # amqp routing key
                  routing_key=None,  # leave empty to use name
-                 headers={},        # amqp headers
-                 context={},        # initial context
+                 headers=None,      # amqp headers
+                 context=None,      # initial context
                  ignore=[],         # exclude from handling
                  logger=None,       # custom logger
                  guid=None,         # provide your own ID
@@ -147,7 +151,7 @@ class Context(object):
                  ):
         self.context = {}
         self._ = _dummy_obj()
-        self._.headers = headers
+        self._.headers = headers or {}
         self._.silent = silent
         self._.guid = guid or str(uuid.uuid4())
         self._.ignore = tuple(ignore)
@@ -201,7 +205,12 @@ class Context(object):
         status = transient and 'transient' or 'born'
         self._update(meta=dict(status=status), context=context)
 
-    def _update(self, msg=[], level=logging.DEBUG, context={}, meta={}, format=True):
+    def _update(self,
+                msg=[],
+                level=logging.DEBUG,
+                context={},
+                meta={},
+                format=True):
         '''
         Logger-like behavior
         '''
@@ -255,8 +264,9 @@ class Context(object):
         return self._update(context=kw)
 
     def __setattr__(self, name, value):
-        if hasattr(Context, name):
+        if hasattr(self.__class__, name):
             if getattr(self, name) is None:
+                # make assignments work (need this in init)
                 object.__setattr__(self, name, value)
             else:
                 raise AttributeError("Attribute '%s' is reserved"
@@ -281,6 +291,22 @@ class Context(object):
             raise AttributeError
         return self.context[name]
 
+    def __delattr__(self, name):
+        if not hasattr(self, 'context'):
+            raise Exception("Context not initialized, call __init__()!")
+        if hasattr(Context, name):
+            raise AttributeError("Attribute '%s' is reserved:"
+                                 " cannot delete" % name)
+        if name in self.context:
+            del self.context[name]
+        else:
+            if self._.obj:
+                delattr(self._.obj)
+            else:
+                raise AttributeError("'%s' has no attribute '%s'" %
+                                     (self, name))
+        self._update(context={name: None}, meta={'action': 'delete'})
+
     def __str__(self):
         return "%s %s" % (self._.name, self._.guid)
 
